@@ -15,7 +15,7 @@ use List::Compare;
 use List::MoreUtils qw(none uniq firstval);
 use Scalar::Util qw(weaken);
 
-our $VERSION = '1.09';
+our $VERSION = '1.10';
 
 my %translation = (
 	2  => 'Polizeiliche Ermittlung',
@@ -69,6 +69,7 @@ my %translation = (
 	64 => 'Weichenstörung',
 	65 => 'Erdrutsch',
 	70 => 'Kein WLAN',
+	71 => 'WLAN in einzelnen Wagen nicht verfügbar',
 	73 => 'Mehrzweckabteil vorne',
 	74 => 'Mehrzweckabteil hinten',
 	75 => '1. Klasse vorne',
@@ -413,7 +414,7 @@ sub canceled_stops {
 sub classes {
 	my ($self) = @_;
 
-	my @classes = split(//, $self->{classes});
+	my @classes = split( //, $self->{classes} );
 
 	return @classes;
 }
@@ -744,7 +745,7 @@ arrival/departure received by Travel::Status::DE::IRIS
 
 =head1 VERSION
 
-version 1.09
+version 1.10
 
 =head1 DESCRIPTION
 
@@ -1204,6 +1205,8 @@ Source: correlation between IRIS and DB RIS (bahn.de).
 
 Source: correlation between IRIS and DB RIS (bahn.de).
 
+=item q 71 : "WLAN in einzelnen Wagen nicht verfE<uuml>gbar"
+
 =item q 73 : "Mehrzweckabteil vorne"
 
 Source: correlation between IRIS and DB RIS (bahn.de).
